# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# if sqlite ≥ 3.6.0 then
#   perl-DBD-SQLite uses the system library
# else
#   perl-DBD-SQLite is self-contained (uses the sqlite local copy)
%global use_system_sqlite %((sqlite3 --version 2>/dev/null || echo 0.0.0.0) | awk -F. '{ ver = sprintf("%d%02d%02d%02d", $1, $2, $3, $4); print ver >= 3060000 ? 1 : 0 }')

# We need Test::More ≥ 0.82, or we have to patch out "note" from the test suite
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.82) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-DBD-SQLite
Version:	1.54
Release:	1.%{__distinit}%{__distvers}
Summary:	Self Contained RDBMS in a DBI Driver
Group:		Development/Libraries
License:	(GPL+ or Artistic) and Public Domain
URL:		http://search.cpan.org/dist/DBD-SQLite/
Source0:	http://search.cpan.org/CPAN/authors/id/I/IS/ISHIGAKI/DBD-SQLite-%{version}.tar.gz
Patch0:		DBD-SQLite-bz543982.patch
Patch1:		DBD-SQLite-1.50-Remove-bundled-source-extensions.patch
Patch10:	DBD-SQLite-1.50-utf8.patch
Patch11:	DBD-SQLite-1.52-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 6 || 0%{?rhel} > 5
BuildRequires:	perl-devel
%endif
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Spec) >= 0.82
BuildRequires:	sed
BuildRequires:	sqlite-devel
# Module Runtime
BuildRequires:	perl(constant)
BuildRequires:	perl(DBI) >= 1.57
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(locale)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Tie::Hash)
# Test Suite
BuildRequires:	perl(Carp)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec::Functions)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(Test::More) >= 0.42
BuildRequires:	perl(Test::NoWarnings)
BuildRequires:	perl(warnings)
# Runtime
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Don't provide private perl objects
%{?perl_default_filter}

%description
SQLite is a public domain RDBMS database engine that you can find at
http://www.sqlite.org/.

%prep
%setup -q -n DBD-SQLite-%{version}

# Build with system SQLite
%if %{use_system_sqlite}
# Enable system sqlite
%patch0
# $(CC) -I. would find the bundled SQLite if these are present
rm -f sqlite3.c sqlite3.h sqlite3ext.h
sed -i -e '/^sqlite/ d' MANIFEST
# Remove notes about bundled sqlite C source from man page and README
%patch1 -p1
%endif

# Recode docs as UTF8
%patch10

# We need Test::More ≥ 0.82, or we have to patch out "note" from the test suite
%if %{old_test_more}
%patch11
%endif

%build
AUTOMATED_TESTING=1 perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%doc Changes README
%{perl_vendorarch}/auto/DBD/
%if ! %{use_system_sqlite}
%{perl_vendorarch}/auto/share/
%endif
%dir %{perl_vendorarch}/DBD/
%{perl_vendorarch}/DBD/SQLite.pm
%dir %{perl_vendorarch}/DBD/SQLite/
%{perl_vendorarch}/DBD/SQLite/Constants.pm
%doc %{perl_vendorarch}/DBD/SQLite/Cookbook.pod
%doc %{perl_vendorarch}/DBD/SQLite/Fulltext_search.pod
%{perl_vendorarch}/DBD/SQLite/VirtualTable.pm
%{perl_vendorarch}/DBD/SQLite/VirtualTable/
%{_mandir}/man3/DBD::SQLite.3*
%{_mandir}/man3/DBD::SQLite::Constants.3*
%{_mandir}/man3/DBD::SQLite::Cookbook.3*
%{_mandir}/man3/DBD::SQLite::Fulltext_search.3*
%{_mandir}/man3/DBD::SQLite::VirtualTable.3*
%{_mandir}/man3/DBD::SQLite::VirtualTable::FileContent.3*
%{_mandir}/man3/DBD::SQLite::VirtualTable::PerlData.3*

%changelog
* Sat Dec 24 2016 Paul Howarth <paul@city-fan.org> - 1.54-1
- Update to 1.54
  - Re-enabled perl tokenizer by calling sqlite_db_config if SQLite ≥ 3.12
  - Resolved trivial documentation bug in DBL::SQLite 1.52 (CPAN RT#119219)

* Tue Nov 15 2016 Paul Howarth <paul@city-fan.org> - 1.52-1
- Update to 1.52
  - Updated bundled SQLite to 3.13.0
  - As upstream disabled two-arg fts3_tokenizer() for security concern,
    DBD::SQLite also stopped enabling it by default; if you do need the perl
    tokenizer, compile/install with SQLITE_ENABLE_FTS3_TOKENIZER environment
    variable
  - Applied a doc patch by Salvatore Bonaccorso
  - Enabled (experimental) FTS5
  - Fixed REGEXP function to work under sqlite_unicode correctly
  - Fixed t/62_regexp_multibyte_char_class.t failing for perl ≥ 5.22.0 and
    non-utf8 locale (CPAN RT#112220)
  - Fixed column_info not parsing sizes with spaces (CPAN RT#115465)
  - Added two missing function declarations
- Update patches as needed

* Mon Jul 25 2016 Paul Howarth <paul@city-fan.org> - 1.50-4
- Enable perl FTS3 tokenizer with sqlite older than 3.11.0 (CPAN RT#112474)
- BR: perl-generators where available
- Simplify find commands using -empty and -delete

* Fri Feb 19 2016 Paul Howarth <paul@city-fan.org> - 1.50-2
- Adjust to sqlite-3.11.0 (#1309675)

* Thu Feb 11 2016 Paul Howarth <paul@city-fan.org> - 1.50-1
- Update to 1.50
  - Updated to SQLite 3.10.2
  - Resolved SAVEPOINT bug (CPAN RT#106151)
  - Made sure to keep what's left in unprepared_statements when
    allow_multiple_statements is set (GH#11)
  - Added a workaround to resolve CPAN RT#106950: Extra warnings with
    savepoints (hopefully)
  - Not to run tests for table_column_metadata unless ENABLE_COLUMN_METADATA
    is set
  - Fixed an sqlite version number in a test (GH#14)
  - Because of the addition of LIKE/GLOB/REGEXP support on virtual tables,
    previous ::PerlData virtual table got broken; this is hopefully fixed by
    adding strlike/strglob functions to DBD::SQLite but if you use this
    virtual table, please test it carefully
  - Now you can make a database connection read-only if you turn on the
    ReadOnly attribute when you connect (CPAN RT#110439); if you set it after
    you connect to a database, DBD::SQLite warns because the database doesn't
    actually become read-only
  - Improved ::Constants
    - To load DBD::SQLite by itself
    - To expose SQLITE_VERSION_NUMBER
    - Introduced a few new (shorter) tags
  - Resolved CPAN RT#111558: Virtual table tests depend on enhanced query
    syntax availability
  - Ignore FTS tests if FTS is not available
- Update patches as needed
- Use system SQLite if it's version 3.6.0 or later

* Fri Jan 15 2016 Paul Howarth <paul@city-fan.org> - 1.48-3
- Adapt to sqlite-3.10.0 by adding DBD::SQLite::strlike() (#1298628)
- Explicitly BR: perl-devel, needed for EXTERN.h

* Mon Jun 22 2015 Paul Howarth <paul@city-fan.org> - 1.48-1
- Update to 1.48
  CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS
  - Commented OPTIMIZE out of WriteMakefile (CPAN RT #94207); if your perl is
    not compiled with -O2, your DBD::SQLite may possibly behave differently
    under some circumstances
  OTHER CHANGES
  - Updated to SQLite 3.8.10 (CPAN RT#35449)
  - Added DBD::SQLite::Constants, from which you can import any "useful"
    constants into your applications
  - Added :all to EXPORT_TAGS in ::Constants
  - Used MY_CXT instead of a global variable
- Update patches as needed
- We now need to use the bundled SQLite unless the system version is at least
  3.8.10.2

* Wed Dec 10 2014 Paul Howarth <paul@city-fan.org> - 1.46-1
- Update to 1.46
  CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS
  - Changed to apply quotemeta() to parameters while building a query for a
    virtual table using PerlData for security
  OTHER CHANGES
  - Updated to SQLite 3.8.7.2
  - int values over 32 bit in length produced an error "datatype mismatch"
    (CPAN RT#76395)
  - Improved int overflow handling under 32bit strawberry perl
  - Fixed regression of 0 as integer
  - Restored regexp support in PerlData virtual table by secure
    re-implementation using closure
  - Silenced a compile-time warning (Unescaped left brace in regex is
    deprecated) in PerlData virtual table under bleadperl
- Update patches as needed

* Wed Oct 22 2014 Paul Howarth <paul@city-fan.org> - 1.44-1
- Update to 1.44
  CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS
  - Resolved CPAN RT#96877: SQL statements should be converted to utf8; if you
    set sqlite_unicode to true, SQL statements will be upgraded to avoid
    inconsistency between embedded params and bind params
  OTHER CHANGES
  - Added -std=gnu99 for solaris gcc users
  - Updated to SQLite 3.8.5, which should fix query planner's issues in SQLite
  - Fixed busy_timeout to accept 0 to disable
  - Resolved CPAN RT#95511: primary_key_info fails to return names for named
    primary keys
  - Resolved CPAN RT#96050: segfault in disconnected sqlite_db_filename
  - Resolved CPAN RT#96494: add SYSTEM TABLE to table_info() type list
  - Supported virtual tables in Perl, and added two sample tables
  - Resolved CPAN RT#97598: crash on disconnect with virtual tables
  - Updated to SQLite 3.8.6, which should fix a unique index issue: see
    http://www.sqlite.org/src/info/9a6daf340df99ba93c for details
  - Resolved CPAN RT#99583: legacy DOS 8.3 filename support incompatible with
    SQLITE WAL journal mode
- Update patches as needed
- Add patch to support building with Test::More < 0.82
- We now need to use the bundled SQLite unless the system version is at least
  3.8.2

* Mon Sep 15 2014 Paul Howarth <paul@city-fan.org> - 1.42-5
- Perl 5.20 rebuild

* Tue Jul 29 2014 Paul Howarth <paul@city-fan.org> - 1.42-3
- Remove notes about bundled sqlite C source from man page and README when
  building with system SQLite
- Classify buildreqs by usage

* Wed Mar 19 2014 Paul Howarth <paul@city-fan.org> - 1.42-1
- Update to 1.42
  - NOTICE ON NEXT GENERATION QUERY PLANNER
    - As of SQLite 3.8.0, SQLite's query planner has been rewritten; according
      to the author, the new query planner should give exactly the same result
      (though perhaps with a little less CPU time spent planning) for simple
      queries, and for complex queries, it can in many cases provide a much
      faster answer (see http://www.sqlite.org/queryplanner-ng.html for
      details)
  - NOTICE ON PARTIAL INDICES
    - Database files created by SQLite 3.8.0 are still readable and writable by
      prior versions, but if you use partial indices introduced in SQLite
      3.8.0, those files become unreadable and unwritable by older versions of
      (DBD::)SQLite; they'll be readable/writable again by dropping partial
      indices
  - Updated to SQLite 3.8.4.1 (CPAN RT#88228), fixing several obscure bugs on
    "ORDER BY" or "DISTINCT"
  - Resolved CPAN RT#87435: statistics_info perldoc
  - Resolved CPAN RT#87297: URI filenames in DBD::SQLite
  - Resolved CPAN RT#90211: Error in documentation
  - Resolved CPAN RT#89351: DBD-SQLite won't compile on Cygwin 64 bit
  - Resolved CPAN RT#92322: Failure under heavily parallelized tests
  - Tweaked sqlite_see_if_its_a_number not to guess data types of bind values
    with explicit type specification (via bind_param() etc.)
  - Disabled Test::NoWarnings in a test
- Drop %%defattr, redundant since rpm 4.4
- Drop upstreamed patches
- Update UTF-8 patch

* Thu Jan 16 2014 Paul Howarth <paul@city-fan.org> - 1.40-2
- Add upstream fix for support of SQLite ≥ 3.8.2
- Add upstream fix for test failure in t/53_status.t (CPAN RT#89011)
- Drop buildreqs needed only for extra tests that aren't run

* Sun Jul 28 2013 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.40
  - NetBSD also doesn't like the _XOPEN_SOURCE hack
  - Add statistics_info support (CPAN RT#86080)
- Re-diff patches

* Wed Jul 24 2013 Paul Howarth <paul@city-fan.org> - 1.39-2
- Perl 5.18 rebuild

* Sun Jun  9 2013 Paul Howarth <paul@city-fan.org> - 1.39-1
- Update to 1.39 (see Changes for details)
- This release by ISHIGAKI -> update source URL
- Re-diff patches
- Add new patch to support building with Test::More < 0.88
- Build with bundled SQLite unless system version is 3.7.13 or later (fails to
  build with older versions)

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 1.37-2
- BR: perl(Carp), perl(constant), perl(Data::Dumper), perl(Encode),
  perl(Exporter), perl(File::Spec::Functions) and perl(File::Temp)

* Sat Jun  9 2012 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37 (see Changes for details)
- Don't need to remove empty directories from the buildroot
- Use pure_install rather than install
- Re-diff patches
- Build with bundled SQLite unless system version is 3.6.22 or later
  (test t/49_trace_and_profile.t fails otherwise)
- Drop support for old distributions prior to FC-3:
  - Always BR: sqlite-devel
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Tue Nov 29 2011 Paul Howarth <paul@city-fan.org> - 1.35-1
- Update to 1.35 (see Changes for details)
- Re-diff UTF-8 patch

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 1.33-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon May 30 2011 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33 (see Changes for details)
- Drop upstreamed patch for building with system SQLite
- Re-diff UTF-8 patch
- Nobody else likes macros for commands

* Fri Oct  1 2010 Paul Howarth <paul@city-fan.org> - 1.31-2
- Rebuild for gcc bug (#634757)

* Wed Sep 15 2010 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31 (see Changes for details)
- Update UTF-8 patch
- Remove bundled SQLite if we're building with system version
- Add patch to support building with a system SQLite that's not built with
  the ENABLE_FTS3_PARENTHESIS option

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.29-3
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  1 2010 Paul Howarth <paul@city-fan.org> - 1.29-2
- Fix dist tag for RHEL-6 Beta

* Mon Apr 12 2010 Paul Howarth <paul@city-fan.org> - 1.29-1
- Import from Fedora
- Update to 1.29
- Enable AUTOMATED_TESTING

* Mon Jan 11 2010 Marcela Mašláňová <mmaslano@redhat.com> - 1.27-3
- 543982 change Makefile.PL to compile with system sqlite

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.27-2
- Rebuild against perl 5.10.1

* Wed Nov 25 2009 Stepan Kasal <skasal@redhat.com> 1.27-1
- New upstream version

* Fri Sep 11 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1.25-4
- Filtering errant private provides

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.25-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jun 10 2009 Stepan Kasal <skasal@redhat.com> - 1.25-2
- Rebuild against DBI 1.609

* Fri May 29 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1.25-1
- 1.25 needed for DBIx::Class 0.08103
- Auto-update to 1.25 (by cpan-spec-update 0.01)
- Added a new br on perl(File::Spec) (version 0.82)
- Altered br on perl(Test::More) (0 => 0.42)
- Added a new br on perl(DBI) (version 1.57)

* Mon Apr 20 2009 Marcela Maslanova <mmaslano@redhat.com> - 1.23-1
- Update to the latest version

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.14-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jun  2 2008 Marcela Maslanova <mmaslano@redhat.com> - 1.14-8

* Wed Mar 19 2008 Chris Weyl <cweyl@alumni.drew.edu> - 1.14-7
- Reenable tests

* Tue Mar 18 2008 Chris Weyl <cweyl@alumni.drew.edu> - 1.14-6
- Apply sanity patches derived from RT#32100

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.14-5.1
- Rebuild for perl 5.10 (again)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.14-4.1
- Autorebuild for GCC 4.3

* Sun Jan 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.14-3.1
- Tests disabled, due to x86_64 failures

* Tue Jan 15 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.14-3
- Rebuild for new perl

* Wed Dec 19 2007 Steven Pritchard <steve@kspei.com> - 1.14-2
- Fix find option order
- Use fixperms macro instead of our own chmod incantation

* Mon Dec 10 2007 Robin Norwood <rnorwood@redhat.com> - 1.14-1
- Update to latest upstream version: 1.14
- Remove patch - no longer needed.

* Mon Oct 15 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.12-2.1
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Thu Sep 14 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.12-2
- Rebuild for FC6

* Tue Apr 11 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.12-1
- Update to 1.12

* Wed Apr  5 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.11-4
- Patch to build with system sqlite 3.3.x (#183530)
- Patch to avoid type information segv (#187873)

* Thu Mar  9 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.11-3
- DBD::SQLite fails to build with the current FC-5 sqlite version (3.3.3);
  see bugzilla entry #183530
- Forcing package rebuild with the included version of sqlite (3.2.7)

* Sat Feb 18 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.11-2
- Rebuild for FC5 (perl 5.8.8)

* Fri Dec  2 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.11-1
- Update to 1.11

* Fri Dec  2 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.10-1
- Update to 1.10

* Fri Jul 29 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.09-2
- Build requirement added: sqlite-devel
- Doc file added: Changes

* Fri Jul 29 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.09-1
- Update to 1.09
- This new version can use an external SQLite library (>= 3.1.3)

* Sun Jun 12 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.08-2
- Temporary maintainership

* Sat Jun 11 2005 Michael A. Peters <mpeters@mac.com> - 1.08-1.1
- Minor changes for initial cvs checkin (removed tabs, better url in
  url tag and description tag)

* Tue Apr 12 2005 Michael A. Peters <mpeters@mac.com> - 1.08-1
- Created initial spec file from Fedora spectemplate-perl.spec
